#!/bin/bash

# $1 is used as the host name.
EUREKA_URI="http://${EUREKA_SERVER:-192.168.2.21:7777}"
echo $EUREKA_URI
APP_NAME=${SERVICE_NAME:-fake}
SERVICE_HOST=${EXTERNAL_HOST:-fakehost.com}
SERVICE_PORT=${EXTERNAL_PORT:-80}
CROSS_HEADER=${CROSS_ORIGIN:-false}

INTERVAL_TIME=${INTERVAL:-30}
SERVICE_PROTOCOL="http"
SERVICE_URI="$SERVICE_PROTOCOL://$SERVICE_HOST:$SERVICE_PORT"
HOME_URI="$SERVICE_URI/"
HEALTH_URI="$SERVICE_URI/"
STATUS_URI="$SERVICE_URI/"
HOST_NAME="${HOSTNAME:-fake01}"

function regist2eureka {

  cat <<EOF >/tmp/json.json
{
  "instance": {
    "app": "$APP_NAME",
    "dataCenterInfo": {
      "@class": "com.netflix.appinfo.MyDataCenterInfo",
      "name": "MyOwn"
    },
    "healthCheckUrl": "$HEALTH_URI",
    "homePageUrl": "$HOME_URI",
    "hostName": "$HOST_NAME",
    "ipAddr": "$SERVICE_HOST",
    "leaseInfo": {
        "renewalIntervalInSecs": 120,
      "evictionDurationInSecs": 3600
    },
    "metadata": {
      "owner": "Strike",
      "cost-code": "9527",
      "cross-origin": "${CROSS_HEADER}"
    },
    "port": {
      "\$": "$SERVICE_PORT",
      "@enabled": "true"
    },
    "securePort": {
      "\$": 443,
      "@enabled": "false"
    },
    "secureVipAddress": null,
    "status": "UP",
    "statusPageUrl": "$STATUS_URI",
    "vipAddress": null
  }
}
EOF
  echo $EUREKA_URI/eureka/apps/${APP_NAME}
  curl -v --header "content-type: application/json" \
    --data-binary @/tmp/json.json \
    $EUREKA_URI/eureka/apps/${APP_NAME}

}

function sendHeartbeats {
  echo $EUREKA_URI/eureka/apps/${APP_NAME}/$HOST_NAME
  curl -v --header "content-type: application/json" \
    -X POST \
    $EUREKA_URI/eureka/apps/${APP_NAME}/$HOST_NAME
  regist2eureka
}

while true; do
  sendHeartbeats
  sleep $INTERVAL_TIME
done
