import { ConfigProvider, Tabs } from "antd";
import { useMemo } from "react";
import IssueDescription from "./IssueDescription";
import SignLeft from "./SignLeft";
import SignTop5 from "./SignTop";
import styles from "./index.less";
import PointsAgainst from "./PointsAgainst";
import SystemIndex from "./SystemIndex";
import CountyTop from "./CountyTop";
export default ({
  item,
  lineData,
}: {
  item: { indexId: string; IndexName: string; name?: string };
  lineData?: any[];
}) => {
  const tabItems = useMemo(() => {
    return [
      {
        label: `失分溯源`,
        key: "1",
        children: <PointsAgainst indexId={item?.indexId} />,
      },
      {
        label: `影响体征TOP5`,
        key: "2",
        children: <SignTop5 items={item} />,
      },
      {
        label: `${item?.IndexName || item?.name}问题`,
        key: "3",
        children: <IssueDescription indexId={item.indexId} />,
      },
      {
        label: `指标体系`,
        key: "4",
        children: <SystemIndex indexId={item.indexId} />,
      },
      {
        label: `市区县排名`,
        key: "5",
        children: (
          <CountyTop indexId={item?.indexId} indexName={item?.indexName} />
        ),
      },
    ];
  }, [item]);

  return (
    <div className={styles.container}>
      <SignLeft data={item} lineData={lineData} />
      <div className={styles.right}>
        <ConfigProvider
          theme={{
            components: {
              Tabs: {
                itemColor: "#6A738E",
                inkBarColor: "#2B85FF",
                itemActiveColor: "#2B85FF",
                itemHoverColor: "#2B85FF",
                itemSelectedColor: "#2B85FF",
                horizontalItemGutter: 70,
              },
            },
          }}
        >
          <Tabs size="large" defaultActiveKey="1" centered items={tabItems} />
        </ConfigProvider>
      </div>
    </div>
  );
};
