import { useEffect, useMemo, useState } from "react";
import ReactECharts from "echarts-for-react";

import * as echarts from "echarts";
import styles from "./index.less";
import { Flex } from "antd";
import { gaugeOption, barOption } from "./option";
import { getColorByIndex } from "@/utils/ui";
import { cloneDeep } from "lodash";
import { log } from "echarts/types/src/util/log.js";

interface SituationOverviewProps {
  dataSource?: any;
  loading?: boolean;
  lineDate?: any;
  title?:string
}

/** @name 态势总览 */
const SituationOverview: React.FC<SituationOverviewProps> = ({
  dataSource,
  loading,
  lineDate,
  title
}) => {

  
  const newGaugeOption = useMemo(() => {
    const value = dataSource?.currentIndex?.cqi ?? 0;
    const temp = cloneDeep(gaugeOption) as any;

    temp.series[0].data[0].value = Number(value);
    return temp;
  }, [dataSource]);

  const newBarOption = useMemo(() => {
    const areaData = lineDate?.data || [];
    const xAxisData = areaData.map((item: any) => item.objectName);
    const seriesData = areaData.map((item: any) => ({
      value: Number(item.cqi),
      name: item.objectName,
      itemStyle: {
        color: getColorByIndex(Number(item.cqi)),
      },
    }));
    const temp = cloneDeep(barOption);
    (temp.series as echarts.SeriesOption[])[0].data = seriesData;
    (temp.xAxis as any[])[0].data = xAxisData;
    return temp;
  }, [lineDate]);

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>成都市{title}态势总览</div>
        <div className={styles.header_time}>
          更新时间 {dataSource?.currentIndex?.time}
        </div>
      </Flex>
      <Flex align="center" justify="center" className={styles.gaugeChart}>
        <ReactECharts
          style={{ width: 500, height: 150 }}
          option={newGaugeOption}
        />
        <div className={styles.chart_status}>
          {dataSource?.currentIndex?.status}
        </div>
      </Flex>
      <div className={styles.gaugeTitle}>{title}今日体征指数</div>
      <div className={styles.barChart}>
        <ReactECharts
          option={newBarOption}
          style={{ width: "100%", height: 150 }}
        ></ReactECharts>
      </div>
    </div>
  );
};

export default SituationOverview;
