import React, { forwardRef, Ref, useImperativeHandle, useState } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { List } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import Tabs from "../Tabs";
import VirtualList from "rc-virtual-list";
import NormalcyCard from "./NormalcyCard";

interface NormalcyLawModalProps {
  data?: any;
}

interface CardProps {
  title?: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const ContainerHeight = 620;

const NormalcyLawModal = forwardRef<CleanRangeModalMethod, NormalcyLawModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);
  const [activeKey, setActiveKey] = useState("1");

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const onScroll = (e: React.UIEvent<HTMLElement, UIEvent>) => {
    if (
      Math.abs(
        e.currentTarget.scrollHeight -
          e.currentTarget.scrollTop -
          ContainerHeight
      ) <= 1
    ) {
      console.log("到底了,可以加载更多");
    }
  };

  const getFilteredCases = () => {
    const allCases = data?.cases || [];
    switch (activeKey) {
      case "2": // 处置中
        return allCases.filter((item: any) => item.status === 2);
      case "3": // 已结案
        return allCases.filter((item: any) => item.status === 1);
      default: // 全部
        return allCases;
    }
  };

  const filteredCases = getFilteredCases();

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="常态执法"
        onCancel={action.setFalse}
        width={1550}
      >
        <Card w={1458} h={761}>
          <Tabs
            items={[
              { label: "全部", key: "1" },
              { label: "处置中", key: "2" },
              { label: "已结案", key: "3" },
            ]}
            activeKey={activeKey}
            onClick={setActiveKey}
          />
          <List style={{ marginTop: 20 }}>
            <VirtualList
              data={filteredCases}
              height={ContainerHeight}
              itemKey={(item) => item.id || item.time}
              onScroll={onScroll}
            >
              {(item: any, index) => (
                <NormalcyCard
                  key={item.id || item.time}
                  index={index}
                  data={item}
                />
              )}
            </VirtualList>
          </List>
        </Card>
      </BaseModal>
    </div>
  );
});

export default NormalcyLawModal;
