import { useMemo } from "react";
import ReactECharts from "echarts-for-react";
import styles from "./index.less";
import { Flex } from "antd";
import { gaugeOption, barOption } from "./option";
import { getColorByIndex } from "@/utils/ui";
import { cloneDeep } from 'lodash';

interface SituationOverviewProps {
  data?: any;
  loading?: boolean;
}

/** @name 成都市行政执法态势总览 */
const SituationOverview: React.FC<SituationOverviewProps> = ({ data }) => {
  const newGaugeOption = useMemo(() => {
    const temp = cloneDeep(gaugeOption);
    (temp.series as any)[0].data[0].value = data?.currentIndex?.cqi || 0;
    return temp;
  }, [data]);

  const newBarOption = useMemo(() => {
    const areaData = data?.areaIndexes || [];
    const xAxisData = areaData.map((item: any) => item.objectName);
    const seriesData = areaData.map((item: any) => ({
      value: item.cqi,
      name: item.objectName,
      itemStyle: {
        color: getColorByIndex(item.cqi),
      },
    }));
    
    const temp = cloneDeep(barOption);
    (temp.series as any)[0].data = seriesData;
    (temp.xAxis as any)[0].data = xAxisData;
    return temp;
  }, [data]);

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>成都市行政执法态势总览</div>
        <div className={styles.header_time}>更新时间 {data?.currentIndex?.time}</div>
      </Flex>
      <Flex align="center" justify="center" className={styles.gaugeChart}>
        <ReactECharts
          style={{ width: 500, height: 150 }}
          option={newGaugeOption}
        />
        <div className={styles.chart_status}>{data?.currentIndex?.status}</div>
      </Flex>
      <div className={styles.gaugeTitle}>行政执法今日体征指数</div>
      <div className={styles.barChart}>
        <ReactECharts
          option={newBarOption}
          style={{ width: "100%", height: 150 }}
        />
      </div>
    </div>
  );
};

export default SituationOverview;
