import React, { useEffect } from "react";
import styles from "./index.less";
import SituationOverview from "@/components/SituationOverview";
import ProblemOverview from "./components/ProblemOverview";
import DomainEventSituationDistribution from "./components/DomainEventSituationDistribution";
import { useGenericData } from "@/hooks/useGenericData";
import { initializeGenericData } from "@/services/GenericData";
import { administrativeLawMockData } from "./mockData";
import { useRequest } from "ahooks";
import services from "@/services";
const indexId = 206;
/** @name 行政执法 */
const AdministrativeLawEnforcement: React.FC = () => {
  const { data: lineDate, loading: lineLoading } = useRequest(() =>
    services.overall.getSolidWasteAreaIndex({
      physicalSignType: 1,
      indexType: 0,
      indexId: indexId,
      sort: "desc",
      objectHierarchy: 1,
      objectId: 1,

    })
  );
  const { data: gaugeData, loading: gaugeLoading } = useRequest(() =>
    services.overall.getIndexInstance({
      industryId: indexId,
      objectId: 1,
    })
  );
  // 使用通用数据服务
  const { dataSource, loading, fetchData } = useGenericData({
    module: "administrative-law",
    type: "overview",
    onError: (error) => {
      console.error("获取数据失败:", error);
    },
  });

  // 初始化数据
  useEffect(() => {
    const initData = async () => {
      try {
        const response = await fetchData();
        if (!(response as any)?.data?.items?.length) {
          await initializeGenericData(
            "administrative-law",
            "overview",
            administrativeLawMockData as any
          );
          fetchData();
        }
      } catch (error) {
        console.error("初始化数据失败:", error);
      }
    };
    initData();
  }, []);

  // 获取第一条数据
  const data = (dataSource as any)?.[0];

  return (
    <div className={styles.container}>
      <SituationOverview
        dataSource={gaugeData?.data}
        loading={gaugeLoading || lineLoading}
        lineDate={lineDate}
        title={'行政执法'}
      />
      <ProblemOverview data={data?.problemOverview} loading={loading} />
      <DomainEventSituationDistribution
        data={data?.domainEvents}
        loading={loading}
      />
    </div>
  );
};

export default AdministrativeLawEnforcement;
