import React, { useRef, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";
import ShopModal, { CleanRangeModalMethod } from "../ShopModal";
import BikeSharingModal from "../BikeSharingModal";
import SignpaintModal from "../SignpaintModal";

interface DomainEventSituationDistributionProps {
  data?: any;
}

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC<DomainEventSituationDistributionProps> = ({ data }) => {
  const [curLocation, setCurLocation] = useState<"today">("today");
  const shopRef = useRef<CleanRangeModalMethod>(null);
  const bikeSharingRef = useRef<CleanRangeModalMethod>(null);
  const signpaintRef = useRef<CleanRangeModalMethod>(null);

  const menu = [
    {
      name: "门前三包",
      value: data?.shop?.count || 0,
      icon: require("@/assets/images/advertisement/mendianIcon.png"),
      onClick: () => {
        shopRef.current?.show();
      },
    },
    {
      name: "共享单车",
      value: data?.bikeSharing?.count || 0,
      icon: require("@/assets/images/advertisement/gonxiangdancheIc.png"),
      onClick: () => {
        bikeSharingRef.current?.show();
      },
    },
    {
      name: "户外广告招牌",
      value: data?.signboard?.count || 0,
      icon: require("@/assets/images/advertisement/guanggaopaiIc.png"),
      onClick: () => {
        signpaintRef.current?.show();
      },
    },
  ];

  return (
    <div className={styles.container}>
      <ShopModal ref={shopRef} data={data?.shop?.details} />
      <BikeSharingModal ref={bikeSharingRef} data={data?.bikeSharing?.details} />
      <SignpaintModal ref={signpaintRef} data={data?.signboard?.details} />
      
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>领域事件态势分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      <Flex gap={35} className={styles.listWrap}>
        {menu.map((item, index) => (
          <div
            className={styles.GradientBorder}
            key={index}
            onClick={item.onClick}
          >
            <div className={styles.itemCard}>
              <Space>
                <div className={styles.itemVal}>{item.value}</div>
                <div className={styles.itemUnit}>件</div>
              </Space>
              <div className={styles.itemName}>{item.name}</div>
              <div className={styles.itemImgWrap}>
                <img src={item.icon} alt="" />
              </div>
            </div>
          </div>
        ))}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
