import React, { useState, useMemo } from "react";
import styles from "./index.less";
import { Flex, Space } from "antd";
import classNames from "classnames";
import BaseDesc from "@/components/BaseDesc";
import ReactECharts from "echarts-for-react";
import { lineOption } from "./option";
import { cloneDeep } from 'lodash';

interface ProblemOverviewProps {
  data?: any;
}

/** @name 问题概况 */
const ProblemOverview: React.FC<ProblemOverviewProps> = ({ data }) => {
  const [curLocation, setCurLocation] = useState<"today">("today");

  const newLineOption = useMemo(() => {
    if (!data?.trend) return lineOption;

    const temp = cloneDeep(lineOption);
    const trendData = data.trend;
    
    (temp.xAxis as any)[0].data = trendData.map((item: any) => item.date);
    (temp.series as any)[0].data = trendData.map((item: any) => item.value);
    
    return temp;
  }, [data]);

  return (
    <div className={styles.container}>
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>问题概况</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      <Flex className={styles.infoWrap} justify="space-between">
        <div>
          <BaseDesc
            value={data?.total || 0}
            name="问题总数"
            unit="件"
            align="center"
          />
        </div>
        <div>
          <BaseDesc
            value={data?.pending || 0}
            name="待处置"
            align="center"
            unit="件"
          />
        </div>
        <div>
          <BaseDesc
            value={data?.rate || 0}
            name="处置率"
            align="center"
            unit="%"
          />
        </div>
      </Flex>
      <div className={styles.barChart}>
        <ReactECharts
          option={newLineOption}
          style={{ width: "100%", height: 180 }}
        />
      </div>
    </div>
  );
};

export default ProblemOverview;
