import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import FacilityInfoCard from "@/pages/MunicipalFacilities/components/PipeModal/components/FacilityInfoCard";

interface ShopModalProps {
  data?: any;
}

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const ShopModal = forwardRef<CleanRangeModalMethod, ShopModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title="门前三包"
        onCancel={action.setFalse}
        width={815}
      >
        <div className={styles.content}>
          <Flex gap={15} justify="space-between">
            <div className={styles.leftWarp}>
              <FacilityInfoCard 
                style={{ height: 242, width: '100%', marginBottom: 15 }} 
                data={{
                  count: data?.basicInfo?.totalShops || 0,
                  unit: "户",
                  label: "全市商户数"
                }}
              />
              <FacilityInfoCard 
                style={{ height: 242, width: '100%', marginBottom: 15 }}
                data={{
                  count: data?.basicInfo?.signedShops || 0,
                  unit: "户",
                  label: '"门前三包"签户数'
                }}
              />
              <FacilityInfoCard 
                style={{ height: 242, width: '100%', marginBottom: 15 }}
                data={{
                  count: data?.basicInfo?.signRate || 0,
                  unit: "%",
                  label: '"门前三包"签约率'
                }}
              />
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default ShopModal;
