import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "@/pages/SolidWaste/components/CleanRangeModal/components/TodayEvent";
import RoadInfoCard from "@/pages/MunicipalFacilities/components/RoadModal/components/RoadInfoCard";
import FacilityInfoCard from "@/pages/MunicipalFacilities/components/PipeModal/components/FacilityInfoCard";
import PieChart from "@/components/PieChart";

interface ConductModalProps {
  info?: {
    seriesName: string;
    data?: any;
  };
}

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const ConductModal = forwardRef<CleanRangeModalMethod, ConductModalProps>(({ info }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const data = info?.data || {};

  console.log(data);

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={info?.seriesName}
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <div className={styles.leftTopWarp}>
                <RoadInfoCard
                  data={{
                    label: "近一月应急事件总量",
                    count: <span style={{ color: "red" }}>{data?.monthlyEvents?.total || 0}</span>,
                    unit: "件",
                  }}
                  style={{ height: 62, marginRight: 20 }}
                />
                <RoadInfoCard
                  style={{ height: 62 }}
                  data={{
                    label: "平均处置时长",
                    count: data?.monthlyEvents?.avgDuration || 0,
                    unit: "小时/件",
                  }}
                />
              </div>
              <div className={styles.leftButtomWarp}>
                <Card title="调度资源情况" w={369} h={670}>
                  <div className={styles.dispatchWarp}>
                    <FacilityInfoCard
                      style={{ height: 90, width: 283 }}
                      data={{
                        count: data?.resources?.videos || 0,
                        unit: "路",
                        label: "调度视频",
                      }}
                    />
                    <FacilityInfoCard
                      style={{ height: 90, width: 283 }}
                      data={{
                        count: data?.resources?.personnel || 0,
                        unit: "人",
                        label: "调度人员",
                      }}
                    />
                    <FacilityInfoCard
                      style={{ height: 90, width: 283 }}
                      data={{
                        count: data?.resources?.equipment || 0,
                        unit: "件",
                        label: "调度装备",
                      }}
                    />
                  </div>
                </Card>
                <Card
                  title="参与力量类型"
                  style={{ marginLeft: 20 }}
                  w={486}
                  h={670}
                >
                  <PieChart
                    vertical={true}
                    style={{ width: "100%", marginTop: 30 }}
                    chartStyle={{ width: 231, height: 231 }}
                    labelGap={22}
                    labelClassName={styles.labelClassName}
                    data={data?.forceTypes || []}
                  />
                </Card>
              </div>
            </div>
            <Card title="今日事件" w={566} h={761}>
              <TodayEvent data={data?.todayEvents || []} />
            </Card>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default ConductModal;
