import { useMemo, useRef, useState } from "react";
import ReactECharts from "echarts-for-react";
import styles from "./index.less";
import { Flex } from "antd";
import { option } from "./option";
import ConductModal from "../ConductModal";
import { cloneDeep } from 'lodash';

interface TrendLineProps {
  data?: any;
  loading?: boolean;
}

/** @name 趋势线 */
const TrendLine: React.FC<TrendLineProps> = ({ data }) => {
  const modalRef = useRef(null);
  const chartRef = useRef(null);
  const [itemInfo, setItemInfo] = useState<any>();

  const newOption = useMemo(() => {
    console.log(data);
    if (!data) return option([], [], []);

    const dailyData = data.daily || [];
    const emergencyData = data.emergency || [];
    const specialData = data.special || [];

    const temp = cloneDeep(option(
      emergencyData,
      dailyData,
      specialData
    ));

    console.log(temp);
    return temp;
  }, [data]);

  const getDataByName = (name: string) => {
    switch (name.toLowerCase()) {
      case '应急指挥':
        return data?.commandDetails?.emergency || [];
      case '日常指挥':
        return data?.commandDetails?.daily || [];
      case '专项保障':
        return data?.commandDetails?.special || [];
    }
  }

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>指挥调度趋势</div>
      </Flex>

      <div className={styles.gaugeTitle}>单位：件</div>
      <div className={styles.barChart}>
        <ReactECharts
          ref={chartRef}
          option={newOption}
          style={{ width: "100%", height: 190 }}
          onEvents={{
            click: (info: any) => {
              (modalRef.current as any)?.show();
              console.log(info);
              setItemInfo({ 
                seriesName: info.seriesName,
                data: getDataByName(info.seriesName)
              });
              console.log(getDataByName(info.seriesName));
            },
          }}
        />
      </div>
      {itemInfo && <ConductModal ref={modalRef} info={itemInfo} />}
    </div>
  );
};

export default TrendLine;
