import React, { useEffect } from "react";
import styles from "./index.less";
import SituationOverview from "./components/SituationOverview";
import Overview from "./components/Overview";
import TrendLine from "./components/TrendLine";
import { useGenericData } from '@/hooks/useGenericData';
import { initializeGenericData } from '@/services/GenericData';
import { integratedCommandMockData } from './mockData';

/** @name 综合指挥 */
const IntegratedCommand: React.FC = () => {
  // 使用通用数据服务
  const {
    dataSource,
    loading,
    fetchData
  } = useGenericData({
    module: 'integrated-command',
    type: 'overview',
    onError: (error) => {
      console.error('获取数据失败:', error);
    }
  });

  // 初始化数据
  useEffect(() => {
    const initData = async () => {
      try {
        const response = await fetchData();
        if (!(response as any)?.data?.items?.length) {
          await initializeGenericData('integrated-command', 'overview', integratedCommandMockData as any);
          fetchData();
        }
      } catch (error) {
        console.error('初始化数据失败:', error);
      }
    };
    initData();
  }, []);

  // 获取第一条数据
  const data = (dataSource as any)?.[0];

  return (
    <div className={styles.container}>
      <Overview data={data?.overview} loading={loading} />
      <SituationOverview data={data?.areaDistribution} loading={loading} />
      <TrendLine data={data?.trends} loading={loading} />
    </div>
  );
};

export default IntegratedCommand;
