import React, { useRef, useEffect, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";
import PipeModal, { CleanRangeModalMethod } from "../PipeModal";
import RoadModal from "../RoadModal";
import BridgeModal from "../BridgeModal";
import LightingModal from "../LightingModal";
import AiLightingModal from "../AiLightingModal";
import { useGenericData } from '@/hooks/useGenericData';
import { initializeGenericData} from '@/services/GenericData';
import { municipalFacilitiesMockData } from '../../mockData';

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC<{ data: any, loading: boolean }> = ({ data, loading }) => {
  const [curLocation, setCurLocation] = useState<"today">("today");

  const pipeRef = useRef<CleanRangeModalMethod>(null);
  const roadRef = useRef<CleanRangeModalMethod>(null);  
  const bridgeRef = useRef<CleanRangeModalMethod>(null);
  const lightingRef = useRef<CleanRangeModalMethod>(null);
  const ailightingRef = useRef<CleanRangeModalMethod>(null);
  
  // 从dataSource中获取数据
  const facilitiesData = data;

  const menu = [
    {
      name: "管廊",
      value: facilitiesData?.pipe?.count || 0,
      icon: require("@/assets/images/municipalFacilities/pipe.png"),
      onClick: () => {
        pipeRef.current?.show();
      },
    },
    {
      name: "道路",
      value: facilitiesData?.road?.count || 0,
      icon: require("@/assets/images/municipalFacilities/way.png"),
      onClick: () => {
        roadRef.current?.show();
      },
    },
    {
      name: "桥梁",
      value: facilitiesData?.bridge?.count || 0,
      icon: require("@/assets/images/municipalFacilities/bridge.png"),
      onClick: () => {
        bridgeRef.current?.show();
      },
    },
    {
      name: "照明设施",
      value: facilitiesData?.lighting?.count || 0,
      icon: require("@/assets/images/municipalFacilities/illumination.png"),
      onClick: () => {
        lightingRef.current?.show();
      },
    },
    {
      name: "智慧照明",
      value: facilitiesData?.smartLighting?.count || 0,
      icon: require("@/assets/images/municipalFacilities/aiillumination.png"),
      onClick: () => {
        ailightingRef.current?.show();
      },
    },
  ];

  return (
    <div className={styles.container}>
      <PipeModal ref={pipeRef} data={facilitiesData?.pipe?.details} />
      <RoadModal ref={roadRef} data={facilitiesData?.road?.details} />
      <BridgeModal ref={bridgeRef} data={facilitiesData?.bridge?.details} />
      <LightingModal ref={lightingRef} data={facilitiesData?.lighting?.details} />
      <AiLightingModal ref={ailightingRef} data={facilitiesData?.smartLighting?.details} />
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>领域事件态势分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      <Flex gap={20} className={styles.listWrap}>
        {menu.map((item, index) => {
          return (
            <div
              className={styles.GradientBorder}
              key={index}
              onClick={() => {
                item.onClick ? item.onClick() : message.warning("页面待开发");
              }}
            >
              <div className={styles.itemCard} key={index}>
                <Space>
                  <div className={styles.itemVal}>{item.value}</div>
                  <div className={styles.itemUnit}>件</div>
                </Space>
                <div className={styles.itemName}>{item.name}</div>
                <div className={styles.itemImgWrap}>
                  <img src={item.icon} alt=""></img>
                </div>
              </div>
            </div>
          );
        })}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
