import React from "react";
import styles from "./index.less";
import { Circle } from "rc-progress";
import { Flex } from "antd";

interface CleanlinessProps {
  data: {
    roadCount: number;      // 道路条数
    shouldSweepCount: number; // 应清扫遍数
    sweptCount: number;     // 今日已清扫遍数
    roads: Array<{
      name: string;
      value: number;
      total: number;
    }>;
  };
}

const Cleanliness: React.FC<CleanlinessProps> = ({ data }) => {
  console.log(data);
  return (
    <div className={styles.container}>
      <Flex gap={12}>
        <div className={styles.card}>
          <Flex justify="space-between" align="center">
            <div>道路条数</div>
            <div>
              <span>{data.roadCount}</span>条
            </div>
          </Flex>
        </div>
        <div className={styles.card}>
          <Flex justify="space-between" align="center">
            <div>应清扫遍数</div>
            <div>
              <span>{data.shouldSweepCount}</span>遍
            </div>
          </Flex>
        </div>
        <div className={styles.card}>
          <Flex justify="space-between" align="center">
            <div>今日已清扫遍数</div>
            <div>
              <span>{data.sweptCount}</span>遍
            </div>
          </Flex>
        </div>
      </Flex>
      <div className={styles.subtitle}>各级道路清扫遍数</div>
      <Flex justify="space-between">
        {data?.roads?.map((item, index) => {
          return (
            <div key={index}>
              <div className={styles.circleProgress}>
                <Circle
                  percent={(item.value / item.total) * 100}
                  strokeWidth={12}
                  trailWidth={6}
                  strokeLinecap="butt"
                  trailColor="rgb(208, 225, 241)"
                  strokeColor="rgb(255, 155, 93)"
                />
                <div className={styles.circleText}>
                  <span>{item.value}</span>/{item.total}
                </div>
              </div>
              <div className={styles.circleTitle}>{item.name}</div>
            </div>
          );
        })}
      </Flex>
    </div>
  );
};

export default Cleanliness;
