import React from "react";
import styles from "./index.less";
import { Flex, Image, Space } from "antd";
import { ClockCircleFilled, EnvironmentFilled } from "@ant-design/icons";

interface TodayEventProps {
  data: {
    reported: number;     // 上报数量
    pending: number;      // 待处置数量
    events: Array<{
      title: string;
      time: string;
      address: string;
      image: string;      // 事件图片URL
    }>;
  };
}

const TodayEvent: React.FC<TodayEventProps> = ({ data }) => {
  console.log(data);
  return (
    <div className={styles.container}>
      <Flex gap={12}>
        <div className={styles.card}>
          <Flex justify="space-between" align="center">
            <div>上报</div>
            <div>
              <span className={styles.reportVal}>{data?.reported}</span>条
            </div>
          </Flex>
        </div>
        <div className={styles.card}>
          <Flex justify="space-between" align="center">
            <div>待处置</div>
            <div>
              <span className={styles.pending}>{data?.pending}</span>遍
            </div>
          </Flex>
        </div>
      </Flex>
      <div className={styles.subtitle}>最新事件</div>
      <div className={styles.eventList}>
        {data?.events?.map((item, index) => {
          return (
            <div key={index} className={styles.eventItem}>
              <Flex align="center">
                <Image
                  width={86}
                  height={86}
                  preview={false}
                  src={item.image}
                  fallback="https://example.com/fallback-image.jpg" // 替换为实际的fallback图片URL
                ></Image>
                <div>
                  <div className={styles.eventTitle}>{item.title}</div>
                  <Flex gap={8}>
                    <ClockCircleFilled
                      style={{
                        color: "rgb(106, 115, 142)",
                      }}
                    />
                    <div className={styles.eventTime}>{item.time}</div>
                  </Flex>
                  <Flex gap={8}>
                    <EnvironmentFilled
                      style={{
                        color: "rgb(106, 115, 142)",
                      }}
                    />
                    <div className={styles.eventAddress}>{item.address}</div>
                  </Flex>
                </div>
              </Flex>
            </div>
          );
        })}
      </div>
    </div>
  );
};

export default TodayEvent;
