    // Start of Selection
    import React, {
      CSSProperties,
      forwardRef,
      PropsWithChildren,
      Ref,
      useImperativeHandle,
    } from "react";
    import styles from "./index.less";
    import BaseModal from "@/components/BaseModal";
    import { Flex, Space } from "antd";
    import classNames from "classnames";
    import BaseDesc from "@/components/BaseDesc";
    import { useBoolean } from "ahooks";
    import Cleanliness from "./components/Cleanliness";
    import TodayEvent from "./components/TodayEvent";
    import { useGenericData } from '@/hooks/useGenericData';
    
    interface CardProps {
      title: string;
      w: number;
      h: number;
      style?: CSSProperties;
      className?: string;
    }
    const Card: React.FC<PropsWithChildren<CardProps>> = (props) => {
      const { title, children, w, h, style, className } = props;
      return (
        <div
          className={classNames(styles.card, className)}
          style={{ ...style, width: w, height: h }}
        >
          <div className={styles.cardTitle}>{title}</div>
          <div>{children}</div>
        </div>
      );
    };
    
    export type CleanRangeModalMethod = {
      show: () => void;
      hide: () => void;
    };
    
    interface CleanRangeModalProps {
      data?: any;
    }
    
    const CleanRangeModal = forwardRef<CleanRangeModalMethod, CleanRangeModalProps>(({ data }, ref) => {
      const [visible, action] = useBoolean(false);
    
      useImperativeHandle(ref, () => ({
        show: action.setTrue,
        hide: action.setFalse,
      }));
    
      return (
        <BaseModal
          open={visible}
          title={"清扫保洁"}
          onCancel={action.setFalse}
          width={1524}
        >
          <div className={styles.content}>
            <Flex gap={15}>
              <div>
                <Flex gap={20}>
                  <Card title={"保洁力量"} w={350} h={180}>
                    <Flex gap={12}>
                      <div className={styles.subCard}>
                        <BaseDesc
                          value={data?.workers || 0}
                          name={"环卫工人"}
                          unit={"人"}
                        ></BaseDesc>
                      </div>
                      <div className={styles.subCard}>
                        <BaseDesc
                          value={data?.vehicles || 0}
                          name={"环卫车辆"}
                          unit={"辆"}
                        ></BaseDesc>
                      </div>
                    </Flex>
                  </Card>
                  <Card title={"清扫面积"} w={510} h={180}>
                    <Flex gap={12}>
                      <div className={styles.subCard}>
                        <BaseDesc
                          value={data?.cleanArea?.total || 0}
                          name={"应清扫面积"}
                          unit={"万m2"}
                        ></BaseDesc>
                      </div>
                      <div className={styles.subCard}>
                        <BaseDesc
                          value={data?.cleanArea?.mechanical || 0}
                          name={"机械清扫面积"}
                          unit={"万m2"}
                        ></BaseDesc>
                      </div>
                      <div className={styles.subCard}>
                        <BaseDesc
                          value={data?.cleanArea?.manual || 0}
                          name={"人工清扫面积"}
                          unit={"万m2"}
                        ></BaseDesc>
                      </div>
                    </Flex>
                  </Card>
                </Flex>
                <Card
                  title={"清洁程度"}
                  style={{ marginTop: 20 }}
                  w={880}
                  h={561}
                >
                  <Cleanliness data={data?.cleanliness || []} />
                </Card>
              </div>
              <Card title={"今日事件"} w={566} h={761}>
                <TodayEvent data={data?.todayEvents || []} />
              </Card>
            </Flex>
          </div>
        </BaseModal>
      );
    });
    
    export default CleanRangeModal;
