import React, { useRef, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";

import CleanRangeModal, { CleanRangeModalMethod } from "../CleanRangeModal";
import { useBoolean } from "ahooks";
import RefuseDisposalModal from "../RefuseDisposalModal";
import PantryRubbishModal from "../PantryRubbishModal";
import RaiseDustModal from "../RaiseDustModal";

interface DomainEventSituationDistributionProps {
  data?: any;
  loading?: boolean;
}

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC<DomainEventSituationDistributionProps> = ({ 
  data,
  loading 
}) => {
  const [curLocation, setCurLocation] = useState<"today">("today");

  const CleanRef = useRef<CleanRangeModalMethod>(null);
  const disposalRef = useRef<CleanRangeModalMethod>(null);
  const antryRubbishRef = useRef<CleanRangeModalMethod>(null);
  const raiseDustRef = useRef<CleanRangeModalMethod>(null);

  // 菜单配置
  const menu = [
    {
      name: "清扫保洁",
      value: data?.cleanSweep?.count || 0,
      icon: require("@/assets/images/solidWaste/qingshao.png"),
      onClick: () => {
        CleanRef.current?.show();
      },
    },
    {
      name: "垃圾处置",
      value: data?.refuseDisposal?.count || 0,
      icon: require("@/assets/images/solidWaste/lajichuzhi.png"),
      onClick: () => {
        disposalRef.current?.show();
      },
    },
    {
      name: "餐厨垃圾",
      value: data?.kitchenWaste?.count || 0,
      icon: require("@/assets/images/solidWaste/canculaji.png"),
      onClick: () => {
        antryRubbishRef.current?.show();
      },
    },
    {
      name: "扬尘监管",
      value: data?.dustControl?.count || 0,
      icon: require("@/assets/images/solidWaste/yangchenjianguan.png"),
      onClick: () => {
        raiseDustRef.current?.show();
      },
    },
  ];

  return (
    <div className={styles.container}>
      <CleanRangeModal ref={CleanRef} data={data?.cleanSweep?.details} />
      <RefuseDisposalModal ref={disposalRef} data={data?.refuseDisposal?.details} />
      <PantryRubbishModal ref={antryRubbishRef} data={data?.kitchenWaste?.details} />
      <RaiseDustModal ref={raiseDustRef} data={data?.dustControl?.details} />

      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>领域事件态势分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>

      <Flex gap={20} className={styles.listWrap}>
        {menu.map((item, index) => (
          <div
            className={styles.GradientBorder}
            key={index}
            onClick={item.onClick}
          >
            <div className={styles.itemCard}>
              <Space>
                <div className={styles.itemVal}>{item.value}</div>
                <div className={styles.itemUnit}>件</div>
              </Space>
              <div className={styles.itemName}>{item.name}</div>
              <div className={styles.itemImgWrap}>
                <img src={item.icon} alt="" />
              </div>
            </div>
          </div>
        ))}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
