import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex, Space } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "../CleanRangeModal/components/TodayEvent";
import PieChart from "@/components/PieChart";

interface CardProps {
  title: React.ReactNode;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children?: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

interface PantryRubbishModalProps {
  data?: any;
}

const PantryRubbishModal = forwardRef<CleanRangeModalMethod, PantryRubbishModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={"餐厨垃圾"}
        onCancel={action.setFalse}
        width={1524}
      >
      <div className={styles.content}>
        <Flex gap={15}>
          <div>
            <Card
              title={
                <div className={styles.disposeTitle}>
                  昨日生活垃圾末端处置量
                  <span>
                    <span className={styles.count}>{data?.facilitiesCount || 0}</span>
                    <span>座</span>
                  </span>
                </div>
              }
              w={881}
              h={389}
            >
              {/* ... 处置设施信息展示 */}              
              <div className={styles.descContent}>
                <img src={data?.yesterdayInfo1?.image} alt="" className={styles.img} />
                <div className={styles.desc}>
                  <div className={styles.title}>
                    {data?.yesterdayInfo1?.name}
                  </div>
                  <div className={styles.info}>
                    {data?.yesterdayInfo1?.description}
                  </div>
                </div>
              </div>
              
              <div className={styles.descContent}>
                <img src={data?.yesterdayInfo2?.image} alt="" className={styles.img} />
                <div className={styles.desc}>
                  <div className={styles.title}>
                    {data?.yesterdayInfo2?.name}
                  </div>
                  <div className={styles.info}>
                    {data?.yesterdayInfo2?.description}
                  </div>
                </div>
              </div>
            </Card>
            <Card
              title="市级项目餐厨垃圾无害化处理量（昨日）"
              style={{ marginTop: 20 }}
              w={881}
              h={345}
            >
              <PieChart
                chartOptions={{
                  title: {
                    text: `${data?.totalProcessing || 0}吨`,
                    subtext: "处理总量",
                    top: "85px",
                    x: "center",
                    textStyle: { color: "#6a738e", fontSize: 18 },
                    subtextStyle: {
                      color: "#6a738e",
                      fontSize: 14,
                    },
                  },
                }}
                style={{ width: "100%" }}
                chartStyle={{ width: 216, height: 216 }}
                labelGap={22}
                labelClassName={styles.labelClassName}
                data={data?.processingData || []}
              />
            </Card>
          </div>
          <Card title="今日事件" w={566} h={761}>
            <TodayEvent data={data?.todayEvents || []} />
          </Card>
        </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default PantryRubbishModal;
