import React, { useEffect } from "react";
import styles from "./index.less";

import ProblemOverview from "./components/ProblemOverview";
import DomainEventSituationDistribution from "./components/DomainEventSituationDistribution";
import { useGenericData } from "@/hooks/useGenericData";
import { initializeGenericData } from "@/services/GenericData";
import { solidWasteMockData } from "./mockData";
import { useRequest } from "ahooks";
import services from "@/services";
import SituationOverview from "@/components/SituationOverview";
const indexId = 204;
/** @name 环卫总览 */
const SolidWaste: React.FC = () => {
  const { data: gaugeData, loading: gaugeLoading } = useRequest(() =>
    services.overall.getIndexInstance({
      industryId: indexId,
      objectId: 1,
    })
  );
  const { data: lineDate, loading: lineLoading } = useRequest(() =>
    services.overall.getSolidWasteAreaIndex({
      physicalSignType: 1,
      indexType: 0,
      indexId: indexId,
      sort: "desc",
      objectHierarchy: 1,
      objectId: 1,
    })
  );
  const { dataSource, fetchData, loading } = useGenericData({
    module: "solid-waste",
    type: "overview",
    onError: (error) => {
      console.error("获取数据失败:", error);
    },
  });

  // 初始化数据
  useEffect(() => {
    const initData = async () => {
      try {
        // 检查是否已有数据
        const response = await fetchData();
        if (!(response as any)?.data?.items?.length) {
          // 如果没有数据,则初始化
          await initializeGenericData(
            "solid-waste",
            "overview",
            solidWasteMockData as any
          );
          fetchData();
        }
      } catch (error) {
        console.error("初始化数据失败:", error);
      }
    };
    initData();
  }, []);

  // 获取第一条数据
  const data = (dataSource as any)?.[0];
  // console.log(dataSource);
  // console.log(data);

  return (
    <div className={styles.container}>
      <SituationOverview
        dataSource={gaugeData?.data}
        loading={gaugeLoading || lineLoading}
        lineDate={lineDate}
        title={'环卫固废'}
      />
      <ProblemOverview data={data?.problemOverview} loading={loading} />
      <DomainEventSituationDistribution
        data={data?.domainEvents}
        loading={loading}
      />
    </div>
  );
};

export default SolidWaste;
