import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import MaintainCompany from "./components/MaintainCompany";
import ProgressBar from "@/pages/MunicipalFacilities/components/PipeModal/components/ProgressBar";
import RoadInfoCard from "@/pages/MunicipalFacilities/components/RoadModal/components/RoadInfoCard";
import FacilityInfoCard from "@/pages/MunicipalFacilities/components/PipeModal/components/FacilityInfoCard";

interface IndustryEveryDayModalProps {
  data?: any;
  onExport?: () => void;
}

interface CardProps {
  title: React.ReactElement | string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const IndustryEveryDayModal = forwardRef<CleanRangeModalMethod, IndustryEveryDayModalProps>(({ data, onExport }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const industryScores = data?.industryScores || {};

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={
          <Flex justify="space-between" style={{ width: "93%" }}>
            <span>行业日常监督</span>
            <span 
              style={{ fontSize: 18, color: "rgb(57, 136, 250)", cursor: 'pointer' }} 
              onClick={onExport}
            >
              导出报表
            </span>
          </Flex>
        }
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <Card title="行业总览" w={671} h={753}>
                <div className={styles.detailContent}>
                  {Object.entries(industryScores).map(([key, value], index) => (
                    <div className={styles.areaItem} key={index}>
                      <span style={{ marginRight: 60 }}>{key}</span>
                      <ProgressBar 
                        style={{ width: 360, height: 20, marginRight: 30 }}
                        value={value as number}
                        unit="分"
                      />
                    </div>
                  ))}
                </div>
              </Card>
            </div>
            <div>
              <Card title="处置反馈情况" w={771} h={214}>
                <div className={styles.feedbackWarp}>
                  {Object.entries(industryScores).map(([key, value], index) => (
                    <RoadInfoCard
                      key={index}
                      data={{
                        label: key,
                        count: value as number,
                        unit: "分"
                      }}
                      style={{width:218, height:53}}
                    />
                  ))}
                </div>
              </Card>
              <Card
                title="评价情况"
                style={{ marginTop: 20 }}
                w={771}
                h={329}
              >
                <MaintainCompany 
                  data={data?.evaluationRanking || []} 
                  scrollY={220}
                />
              </Card>
              <Card
                title="行业总览"
                w={771}
                h={173}
                style={{ marginTop: 20 }}
              >
                <div className={styles.TotalWarp}>
                  <FacilityInfoCard
                    style={{ height: 73, width: 218 }}
                    data={{
                      count: data?.majorIssues?.streetVending || 0,
                      unit: "件",
                      label: data?.majorIssues?.streetVendingLabel
                    }}
                  />
                  <FacilityInfoCard
                    style={{ height: 73, width: 218 }}
                    data={{
                      count: data?.majorIssues?.garbageDumping || 0,
                      unit: "件",
                      label: data?.majorIssues?.garbageDumpingLabel
                    }}
                  />
                  <FacilityInfoCard
                    style={{ height: 73, width: 218 }}
                    data={{
                      count: data?.majorIssues?.lightingMalfunction || 0,
                      unit: "件",
                      label: data?.majorIssues?.lightingMalfunctionLabel
                    }}
                  />
                </div>
              </Card>
            </div>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default IndustryEveryDayModal;
