// import { OptionsDto } from '@/components/TabSwitch';
import { request } from '@umijs/max';

/**
 *
 * @param url 接口地址
 * @returns 首页体征physicalsignindex
 */
const IS_PROD = process.env.NODE_ENV === 'production' ? true : false;
export const reqBaseUrl = IS_PROD ? '/apis/physicalsignindex' : '/apis/physicalsignindex';
const urlProxyApis = (url: string) => {
  return `${reqBaseUrl}${url}`;
};

//体征首页
export async function queryTzzsPhysicalSign(
  data: PhysicalsignApi.QueryTzzsPhysicalSignIndexInstanceDataParams,
): Promise<
  PhysicalsignApi.Result<PhysicalsignApi.QueryTzzsPhysicalSignIndexInstanceDataList>
> {
  return request(
    urlProxyApis(
      `/physicalsignindexinstance/queryIndexInstanceHomepageData`,
    ),
    {
      params: data,
    },
  );
}
//获取体征体系
export async function getPhysicalSignSystem(): Promise<
  PhysicalsignApi.Result<PhysicalsignApi.SignWeightSystem>
> {
  return request(
    urlProxyApis(`/physicalSignModel/getPhysicalSignSystem`),
  );
}
//获取体征权重
export async function getWeightSystem(): Promise<
  PhysicalsignApi.Result<PhysicalsignApi.SignWeightSystem>
> {
  return request(
    urlProxyApis(`/physicalSignModel/getWeightSystem`),
  );
}

//宏观体征首页数据
export async function getMacroscopicPhysicalSign(
  data: PhysicalsignApi.MacroscopicPhysicalSignParams,
): Promise<PhysicalsignApi.Result<PhysicalsignApi.MacroSignIndexTabs>> {
  return request(
    urlProxyApis(`/macroscopicPhysicalSign/getIndexInstance`),
    {
      params: data,
    },
  );
}

//中观体征底部指数
export async function getPhysicalSignIndexTabs(): Promise<
  PhysicalsignApi.Result<PhysicalsignApi.SignIndexTabs>
> {
  return request(
    urlProxyApis(
      `/middlePhysicalSign/getPhysicalSignIndexTabs`
    ),
  );
}

//影响体征Top5
export async function getlistTopNItems(data: {
  objectId?: number;
  indexId?: number;
  n?: number;
}): Promise<PhysicalsignApi.Result<PhysicalsignApi.ListTopNItems>> {
  return request(
    urlProxyApis(
      `/physicalsignindexquestioninstance/listTopNItems`,
    ),
    {
      params: data,
    },
  );
}

//中观体征地图边界
export async function getObjectPolygon(): Promise<
  PhysicalsignApi.Result<PhysicalsignApi.MiddlePolygonItem>
> {
  return request(
    urlProxyApis(
      `/middlePhysicalSign/getObjectPolygon?physicalSignType=1`,
    ),
  );
}

//中观体征县区体征数据
export async function getGroupObjectPhysicalSignIndex(data: {
  physicalSignType: number;
  indexType: number;
}): Promise<
  PhysicalsignApi.Result<{
    objects: PhysicalsignApi.GroupObjectPhysicalSignIndexItem[];
    objGroup: string;
  }>
> {
  return request(
    urlProxyApis(
      `/middlePhysicalSign/getGroupObjectPhysicalSignIndex?physicalSignType=1`,
    ),
    // {
    //   params: data,
    // },
  );
}

// 获取部门行业体征指数
export async function getDepartIndustryPhysicalSignIndex(params: { physicalSignType: string }): Promise<PhysicalsignApi.Result<PhysicalsignApi.DepartIndustryIndexObjectVo>> {
  return request(
    urlProxyApis(`/middlePhysicalSign/getDepartIndustryPhysicalSignIndex`),
    {
      params,
    },
  );
}


// 获取道路图层集合
export async function getRoadLineLayer(params: { physicalSignType: string }): Promise<PhysicalsignApi.Result<PhysicalsignApi.ObjectShapeAndIndexVo[]>> {
  return request(
    urlProxyApis(`/microscopicPhysicalSign/getRoadLineLayer`),
    {
      params,
    },
  );
}

// 获取道路体征指数
export async function getRoadIndexs(params: { physicalSignType: string }): Promise<PhysicalsignApi.Result<PhysicalsignApi.RoadAndGridIndexVo[]>> {
  return request(
    urlProxyApis(`/microscopicPhysicalSign/getRoadIndexs`),
    {
      params,
    },
  );
}
// 获取网格图层集合
export async function getGridPolygonLayer(params: { physicalSignType: string }): Promise<PhysicalsignApi.Result<PhysicalsignApi.ObjectShapeAndIndexVo[]>> {
  return request(
    urlProxyApis(`/microscopicPhysicalSign/getGridPolygonLayer`),
    {
      params,
    },
  );
}

// 获取网格分组体征指数
export async function getGroupGridIndexs(params: { physicalSignType: string }): Promise<PhysicalsignApi.Result<PhysicalsignApi.IndexObjectGridGroupVo[]>> {
  return request(
    urlProxyApis(`/microscopicPhysicalSign/getGroupGridIndexs`),
    {
      params,
    },
  );
}

// 获取指标体系数据
export async function getIndexSystem(id: string): Promise<PhysicalsignApi.Result<PhysicalsignApi.IndexSystemVO>> {
  return request(
    urlProxyApis(`/physicalSignIndex/getIndexSystem`),
    {
      params: {
        indexId: id,
      },
    },
  );
}
// export async function getIndexSystem(id: string): Promise<PhysicalsignApi.Result<PhysicalsignApi.IndexSystemVO>> {
//   return request(
//     urlProxyApis(`/physicalsignindex/physicalSignIndex/getIndexSystem/${id}`),
//   );
// }

// 获取安全问题列表
export async function listTzzsLivePhysicalSignInfluenceFactorQuestionVO(params: PhysicalsignApi.TzzsLivePhysicalSignInfluenceFactorQuestionQueryDTO): Promise<PhysicalsignApi.Result<PhysicalsignApi.TzzsLivePhysicalSignInfluenceFactorQuestionVO[]>> {
  return request(
    urlProxyApis(`/livePhysicalSignInfluenceFactor/listTzzsLivePhysicalSignInfluenceFactorQuestionVO`),
    {
      params,
    },
  );
}
export async function queryTzzsPhysicalSignIndex(data: {
  hierarchyList?: string;
  latest?: boolean;
  objectId?: string;
  indexType?: string;
  indexId?: string;
  objectParentId?: string;
  sortByScore?: boolean;
}): Promise<PhysicalsignApi.Result<PhysicalsignApi.IndexListItem>> {
  return request(
    urlProxyApis(
      `/physicalsignindexinstance/queryTzzsPhysicalSignIndexInstanceDataVO`,
    ),
    {
      params: data,
    },
  );
}